Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4706)

Unified Diff: cc/surfaces/surface_manager.h

Issue 2802023002: Remove SurfaceFactory And SurfaceFactoryClient (Closed)
Patch Set: Rebase Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/surfaces/surface_manager.h
diff --git a/cc/surfaces/surface_manager.h b/cc/surfaces/surface_manager.h
index 53998ec5cb989942e8b64ee9858f5f99d7fe6b4a..3675dc4e181e9fcc809b224d78a887b6fab6274d 100644
--- a/cc/surfaces/surface_manager.h
+++ b/cc/surfaces/surface_manager.h
@@ -36,9 +36,8 @@
namespace cc {
class BeginFrameSource;
class CompositorFrame;
+class CompositorFrameSinkSupport;
class Surface;
-class SurfaceFactory;
-class SurfaceFactoryClient;
namespace test {
class CompositorFrameSinkSupportTest;
@@ -68,7 +67,7 @@ class CC_SURFACES_EXPORT SurfaceManager {
void RequestSurfaceResolution(Surface* pending_surface);
std::unique_ptr<Surface> CreateSurface(
- base::WeakPtr<SurfaceFactory> surface_factory,
+ base::WeakPtr<CompositorFrameSinkSupport> compositor_frame_sink_support,
const LocalSurfaceId& local_surface_id);
// Destroy the Surface once a set of sequence numbers has been satisfied.
@@ -84,8 +83,8 @@ class CC_SURFACES_EXPORT SurfaceManager {
bool SurfaceModified(const SurfaceId& surface_id);
// Called when a CompositorFrame is submitted to a SurfaceFactory for a given
// |surface_id| for the first time.
void SurfaceCreated(const SurfaceInfo& surface_info);
// Require that the given sequence number must be satisfied (using
@@ -103,23 +102,24 @@ class CC_SURFACES_EXPORT SurfaceManager {
// possibly because a renderer process has crashed.
void InvalidateFrameSinkId(const FrameSinkId& frame_sink_id);
// SurfaceFactoryClient, hierarchy, and BeginFrameSource can be registered
// and unregistered in any order with respect to each other.
//
// This happens in practice, e.g. the relationship to between ui::Compositor /
// DelegatedFrameHost is known before ui::Compositor has a surface/client).
// However, DelegatedFrameHost can register itself as a client before its
// relationship with the ui::Compositor is known.
- // Associates a SurfaceFactoryClient with the surface id frame_sink_id it
- // uses.
- // SurfaceFactoryClient and surface namespaces/allocators have a 1:1 mapping.
- // Caller guarantees the client is alive between register/unregister.
- // Reregistering the same namespace when a previous client is active is not
- // valid.
- void RegisterSurfaceFactoryClient(const FrameSinkId& frame_sink_id,
- SurfaceFactoryClient* client);
- void UnregisterSurfaceFactoryClient(const FrameSinkId& frame_sink_id);
+ // Associates a CompositorFrameSinkSupport with the surface id frame_sink_id
+ // it uses.
+ // CompositorFrameSinkSupport and surface namespaces/allocators have a 1:1
+ // mapping.
+ // Caller guarantees |support| is alive between register/unregister.
+ // Reregistering the same namespace when a previous CompositorFrameSinkSupport
+ // is active is not valid.
+ void RegisterCompositorFrameSinkSupport(const FrameSinkId& frame_sink_id,
+ CompositorFrameSinkSupport* client);
+ void UnregisterCompositorFrameSinkSupport(const FrameSinkId& frame_sink_id);
// Associates a |source| with a particular namespace. That namespace and
// any children of that namespace with valid clients can potentially use
@@ -84,8 +83,8 @@ class CC_SURFACES_EXPORT SurfaceManager {
bool SurfaceModified(const SurfaceId& surface_id);
- // Called when a CompositorFrame is submitted to a SurfaceFactory for a given
- // |surface_id| for the first time.
+ // Called when a CompositorFrame is submitted to a CompositorFrameSinkSupport
+ // for a given |surface_id| for the first time.
void SurfaceCreated(const SurfaceInfo& surface_info);
// Require that the given sequence number must be satisfied (using
@@ -103,23 +102,24 @@ class CC_SURFACES_EXPORT SurfaceManager {
// possibly because a renderer process has crashed.
void InvalidateFrameSinkId(const FrameSinkId& frame_sink_id);
- // SurfaceFactoryClient, hierarchy, and BeginFrameSource can be registered
- // and unregistered in any order with respect to each other.
+ // CompositorFrameSinkSupport, hierarchy, and BeginFrameSource can be
+ // registered and unregistered in any order with respect to each other.
//
// This happens in practice, e.g. the relationship to between ui::Compositor /

Powered by Google App Engine
This is Rietveld 408576698